@@ -66,14 +66,14 @@ class RestAPI(object):
 				"rank":1,
 			},
 			"premium": {
-				"plan_id":"prod_I41OYB42aGgfNJ",
+				"plan_id":"prod_I41OYB.....",
 				"rate_limit":10000,
 				"rate_reset":30, # in days.
 				"api_keys":[],
 				"rank":2,
 			},
 			"pro": {
-				"plan_id":"prod_IPiu7aUFXgz53f",
+				"plan_id":"prod_IPiu7a.....",
 				"rate_limit":25000,
 				"rate_reset":30, # in days.
 				"api_keys":[],
